/*
A copyright statement is attached to every file and product created for the
project.  It takes the form of the copyright statement for this 
document:

The project provides a modern way to design and knit garments
using domestic and semi-professional knitting machines.  This document
describes the LockController hardware.

Copyright (C) 2020 Owen Mace and Odile Lambert

This document is free information: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <https://www.gnu.org/licenses/>.
*/
//Coupling from back lock to motor drive
//  All dimensions in mm

$fn = 50;

Tolerance = 0.2;
//Body
BodyLength = 62 - Tolerance * 2;
BodyWidth  = 20 - Tolerance * 2;
BodyDepth  = 5.0;
//Handle
//Slot
SlotLength = BodyLength - 2;
SlotWidth  = 7.0;
SlotDepth  = 1.1;


//Body
difference()
{
  linear_extrude( height = BodyDepth)
    polygon( points = BodyPoints, pathe = BodyPath);
  translate([0, ( BodyWidth - SlotWidth) / 2 , BodyDepth - SlotDepth])
    cube([ SlotLength, SlotWidth, SlotDepth + Tolerance]);
  translate([ BodyLength - 2.5,
              BodyWidth / 2 - 2 - Tolerance,
              BodyDepth - SlotDepth])
    cube([ 3, 4 + Tolerance * 2, 3]);
}
//Add handle
HandleY     = 25;
SphereRadius = 2.5;
translate([ 0, ( BodyWidth + HandleY) / 2, BodyDepth / 2])
  sphere( r = SphereRadius);
translate([ 0, ( BodyWidth - HandleY) / 2, BodyDepth / 2])
  sphere( r = SphereRadius);
translate([ 0, ( BodyWidth - HandleY) / 2, BodyDepth / 2])
rotate([ -90, 0, 0])
  cylinder( h = HandleY, r = SphereRadius);
//Define the Body polygon
BodyPoints = [[ 0             , 0],
              [ BodyLength - 5, 0],
              [ BodyLength    , 1.5],
              [ BodyLength    , BodyWidth - 1.5],
              [ BodyLength - 5, BodyWidth],
              [ 0             , BodyWidth],
              [ 0             , 0]];
BodyPath   =  [ 0, 1, 2, 3, 4, 5, 6];
